@@ -1,5 +1,6 @@
 package Tests;
 
+use parent 'Exporter';
 use strict;
 use warnings;
 
@@ -7,10 +8,8 @@ use Test::More;
 
 my @stats = qw( height width depth size is_root is_leaf );
 
-use base 'Exporter';
-
 our @EXPORT_OK = qw( %runs );
-our $VERSION   = '1.06';
+our $VERSION   = '1.09';
 
 our %runs = (
     stats => {
